#! /bin/bash

# SPDX-FileCopyrightText: 2025 Tobias Schmidl
#
# SPDX-License-Identifier: AGPL-3.0-or-later

# fail immediately on error
set -e
CURLOPT=${CURLOPT:-"--location --remote-time --show-error --silent --fail --tlsv1.2"}

apt-get update  \
	&& apt-get dist-upgrade -y  \
	&& apt-get install -y  \
		apt-file  \
		bash-completion  \
		bat  \
		build-essential  \
		byobu  \
		ca-certificates  \
		cargo  \
		command-not-found  \
		curl  \
		diffr  \
		elinks  \
		eza  \
		fd-find  \
		fzf  \
		git  \
		git-delta  \
		glances  \
		highlight  \
		htop  \
		locales  \
		man  \
		mc  \
		neovim  \
		python3  \
		python3-jedi  \
		python3-neovim  \
		python3-pygments  \
		python3-venv  \
		ranger  \
		ripgrep  \
		tig  \
		zsh  \
	&& apt-get install --no-install-recommends -y  \
		firejail  \
		firejail-profiles  \
		pipx  \
	&&  apt-file update

# shellcheck disable=SC2086
curl $CURLOPT -o /usr/local/sbin/cleanup.sh https://git.schmidl.dev/schtobia/bootstrap/raw/branch/master/cleanup.sh \
	&& chmod u+x /usr/local/sbin/cleanup.sh

# diff-highlight from git is necessary for tig
if [ ! -x /usr/local/bin/diff-highlight ];
then
	echo "#!/usr/bin/perl" > /usr/local/bin/diff-highlight  \
		&& cat /usr/share/doc/git/contrib/diff-highlight/DiffHighlight.pm /usr/share/doc/git/contrib/diff-highlight/diff-highlight.perl >> /usr/local/bin/diff-highlight  \
		&& chmod +x /usr/local/bin/diff-highlight
fi
